@@ -220,8 +220,6 @@ class User(IDBrokerObjectBase):
     first_name: str
     last_name: str
     user_name: str
-    legal_guardians: list[str]
-    legal_wards: list[str]
     context: Dict[str, SchoolContext]
     _gen_class = GenUser
 
@@ -234,10 +232,6 @@ class User(IDBrokerObjectBase):
                 self.first_name == other.first_name,
                 self.last_name == other.last_name,
                 self.user_name == other.user_name,
-                (not self.legal_wards and not other.legal_wards)
-                or (set(self.legal_wards) == set(other.legal_wards)),
-                (not self.legal_wards and not other.legal_wards)
-                or (set(self.legal_guardians) == set(other.legal_guardians)),
                 self.context == other.context,
             )
         )
