@@ -64,7 +64,6 @@ try:
         User,
         WorkGroup,
     )
-    from .utils import get_configured_schools, school_in_configured_schools
 except ImportError:
     # works on the cli in ID Connector Docker container
     # make `idbroker` package importable
@@ -88,21 +87,11 @@ except ImportError:
         User,
         WorkGroup,
     )
-    from idbroker.utils import get_configured_schools, school_in_configured_schools
 
 
 SCHOOL_ATTRS = ["entryUUID", "ou", "displayName"]
 GROUP_ATTRS = ["entryUUID", "cn", "description", "uniqueMember"]
-USER_ATTRS = [
-    "entryUUID",
-    "uid",
-    "givenName",
-    "sn",
-    "memberOf",
-    "ucsschoolRole",
-    "ucsschoolLegalGuardian",
-    "ucsschoolLegalWard",
-]
+USER_ATTRS = ["entryUUID", "uid", "givenName", "sn", "memberOf", "ucsschoolRole"]
 SCHOOL_CLASS_DN_PATTERN = re.compile(
     r"^cn=(?P<cn>.+?),cn=klassen,cn=schueler,cn=groups,ou=(?P<ou>.+?),dc=.+$"
 )
@@ -149,15 +138,11 @@ def verify_users(
     school_authority_name: str,
     fix: bool,
 ) -> None:
-    """
-    Verify users:
-    '(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*)(ucsschoolRole=legal_guardian:*))(LDAP_FILTER))'
-    """
-    role_filter = "(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*)(ucsschoolRole=legal_guardian:*))"
+    """Verify users: '(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))(LDAP_FILTER))'"""
     if ldap_filter:
-        ldap_filter = f"(&{role_filter}({ldap_filter}))"
+        ldap_filter = f"(&(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))({ldap_filter}))"
     else:
-        ldap_filter = role_filter
+        ldap_filter = "(|(ucsschoolRole=teacher:*)(ucsschoolRole=student:*))"
     try:
         ldap_objects: List[Entry] = asyncio.run(get_ldap_objects(ldap_filter, USER_ATTRS))
     except LDAPInvalidFilterError:
@@ -165,24 +150,16 @@ def verify_users(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
+    user_objects = [ldap_object_to_user(o) for o in ldap_objects]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
-    configured_schools = get_configured_schools(school_authority)
-    user_objects = [
-        user
-        for user in asyncio.run(ldap_users_to_id_broker_users(ldap_objects))
-        if any(
-            school_in_configured_schools(school.lower(), configured_schools)
-            for school in user.context.keys()
-        )
-    ]
     id_broker_user = IDBrokerUser(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
             user_objects,
             id_broker_user,
-            Compare(school_authority, no_classes=no_classes, fix=fix).compare_user,
+            Compare(no_classes=no_classes, fix=fix).compare_user,
             parallelism,
             fix=fix,
         )
@@ -216,22 +193,17 @@ def verify_school_classes(
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
+    school_class_objects = [ldap_object_to_school_class(o) for o in ldap_objects]
+    school_class_objects = [o for o in school_class_objects if o is not None]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
-    configured_schools = get_configured_schools(school_authority)
-    school_class_objects = [ldap_object_to_school_class(o) for o in ldap_objects]
-    school_class_objects = [
-        o
-        for o in school_class_objects
-        if o is not None and school_in_configured_schools(o.school.lower(), configured_schools)
-    ]
     id_broker_school_class = IDBrokerSchoolClass(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
             school_class_objects,
             id_broker_school_class,
-            Compare(school_authority, fix=fix).compare_school_group,
+            Compare(fix=fix).compare_school_group,
             parallelism,
         )
     )
@@ -262,23 +234,15 @@ def verify_workgroups(ldap_filter: str, parallelism: int, school_authority_name:
             f"Your LDAP filter is invalid, the complete filter that was used: {ldap_filter}"
         )
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
+    _workgroup_objects = [ldap_object_to_workgroup(o) for o in ldap_objects]
+    workgroup_objects = [o for o in _workgroup_objects if o is not None]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
-    configured_schools = get_configured_schools(school_authority)
-    _workgroup_objects = [ldap_object_to_workgroup(o) for o in ldap_objects]
-    workgroup_objects = [
-        o
-        for o in _workgroup_objects
-        if o is not None and school_in_configured_schools(o.school.lower(), configured_schools)
-    ]
     id_broker_workgroup = IDBrokerWorkGroup(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
-            workgroup_objects,
-            id_broker_workgroup,
-            Compare(school_authority, fix=fix).compare_school_group,
-            parallelism,
+            workgroup_objects, id_broker_workgroup, Compare(fix=fix).compare_school_group, parallelism
         )
     )
 
@@ -309,21 +273,14 @@ def verify_schools(ldap_filter: str, parallelism: int, school_authority_name: st
         )
 
     ldap_objects.sort(key=lambda obj: obj.entry_dn)
+    school_objects = [ldap_object_to_school(o) for o in ldap_objects]
     school_authority = read_id_broker_config(
         config_path=CONFIG_PATH, school_authority_name=school_authority_name
     )
-    configured_schools = get_configured_schools(school_authority)
-    school_objects = [ldap_object_to_school(o) for o in ldap_objects]
-    school_objects = [
-        s for s in school_objects if school_in_configured_schools(s.name.lower(), configured_schools)
-    ]
     id_broker_school = IDBrokerSchool(school_authority, "id_broker")
     asyncio.run(
         get_remote_objects_and_compare(
-            school_objects,
-            id_broker_school,
-            Compare(school_authority, fix=fix).compare_school,
-            parallelism,
+            school_objects, id_broker_school, Compare(fix=fix).compare_school, parallelism
         )
     )
 
@@ -358,11 +315,6 @@ async def dn_to_id(dn: str) -> str:
     return _dn_to_id_cache[dn]
 
 
-async def ldap_users_to_id_broker_users(ldap_objects: List[Entry]) -> List[User]:
-    user_objects = [await ldap_object_to_user(o) for o in ldap_objects]
-    return user_objects
-
-
 def ldap_object_to_school(ldap_object: Entry) -> School:
     return School(
         id=ldap_object.entryUUID.value,
@@ -457,7 +409,7 @@ def ldap_object_to_workgroup(ldap_object: Entry) -> Optional[WorkGroup]:
         return None
 
 
-async def ldap_object_to_user(ldap_object: Entry) -> User:
+def ldap_object_to_user(ldap_object: Entry) -> User:
     if isinstance(ldap_object.ucsschoolRole.value, str):
         ucsschool_roles = [ldap_object.ucsschoolRole.value]
     elif not ldap_object.ucsschoolRole.value:
@@ -533,22 +485,11 @@ async def ldap_object_to_user(ldap_object: Entry) -> User:
                     f"school {school!r} which is missing in their ucsschoolRole attribute.",
                     fg="red",
                 )
-    legal_guardians_dns = ldap_object.ucsschoolLegalGuardian.value
-    legal_wards_dns = ldap_object.ucsschoolLegalWard.value
-    legal_guardians_dns = (
-        [legal_guardians_dns] if isinstance(legal_guardians_dns, str) else legal_guardians_dns
-    )
-    legal_wards_dns = [legal_wards_dns] if isinstance(legal_wards_dns, str) else legal_wards_dns
-
     return User(
         id=ldap_object.entryUUID.value,
         first_name=ldap_object.givenName.value or "N/A",
         last_name=ldap_object.sn.value or "N/A",
         user_name=ldap_object.uid.value,
-        legal_guardians=[await dn_to_id(dn) for dn in legal_guardians_dns]
-        if legal_guardians_dns
-        else [],
-        legal_wards=[await dn_to_id(dn) for dn in legal_wards_dns] if legal_wards_dns else [],
         context=context,
     )
 
@@ -569,14 +510,12 @@ def _empty_classes(context: ContextDictType) -> ContextDictType:
 
 
 class Compare:
-    def __init__(self, school_authority, no_classes: bool = False, fix: bool = False):
-        self.school_authority = school_authority
+    def __init__(self, no_classes: bool = False, fix: bool = False):
         self.no_classes = no_classes
         self.fix = fix
         self.userScheduler = UserScheduler()
         self.groupScheduler = GroupScheduler()
         self.schoolScheduler = SchoolScheduler()
-        self.school_authority = school_authority
 
     async def compare_school(self, local: School, remote: Optional[School]) -> str:
         if not remote:
@@ -584,6 +523,9 @@ class Compare:
                 await self.schoolScheduler.queue_school(local.name)
                 return f"FIX  : {get_name(local)} local={local.dict()!r} remote={remote}"
             return f"FAIL : {get_name(local)}: NOT FOUND on ID Broker server."
+        if remote.display_name.startswith("Traeger"):
+            # error in test data, not in production
+            remote.display_name = remote.display_name[len("TraegerX:") :]
         if local == remote:
             return f"OK   : {get_name(local)}"
         else:
@@ -639,12 +581,6 @@ class Compare:
             local.context = _empty_classes(local.context)
             remote.context = _empty_classes(remote.context)
 
-        # ignore local context of schools that should not be synced
-        configured_schools = get_configured_schools(self.school_authority)
-        for context_school in [str(s) for s in local.context.keys()]:
-            if not school_in_configured_schools(context_school.lower(), configured_schools):
-                del local.context[context_school]
-
         if local == remote:
             return f"OK   : {get_name(local)}"
         else:
@@ -695,7 +631,6 @@ async def get_remote_object_and_compare(
     fix=False,
 ) -> str:
     name = get_name(local_obj)
-
     click.secho(f"{dt_str()} Fetching {name} from ID Broker...", fg="white")
     try:
         remote_obj = await client.get(local_obj.id)
