@@ -284,8 +284,6 @@ def kelvin_user_object(docker_hostname, kelvin_session, random_name, source_uid)
             else {school: sorted([random_name(4), random_name(4)]) for school in schools},
             source_uid=kwargs.get("source_uid", source_uid),
             session=kwargs.get("session", kelvin_session(docker_hostname)),
-            legal_guardians=kwargs.get("legal_guardians", []),
-            legal_wards=kwargs.get("legal_wards", []),
         )
 
     return _func
@@ -540,7 +538,6 @@ async def make_sender_user_special(
     kelvin_session_kwargs,
     docker_hostname,
     id_broker_fqdn,
-    wait_for_kelvin_user_on_id_broker,
 ):
     """
     Fixture factory to create users on the apps host system. They are created
@@ -563,11 +560,7 @@ async def make_sender_user_special(
                 print(f"No user {username!r} on {host!r}.")
 
     async def _make_sender_user_special(
-        roles=("student",),
-        ous=("DEMOSCHOOL",),
-        s_a_name="Traeger1",
-        create_related_users=False,
-        **kwargs,
+        roles=("student",), ous=("DEMOSCHOOL",), s_a_name="Traeger1", **kwargs
     ):
         """
         Creates a user on the hosts UCS system via Kelvin-API-Client
@@ -575,9 +568,6 @@ async def make_sender_user_special(
 
         :param roles: The new users roles
         :param ous: The new users ous
-        :param create_related_users: If a related user should be created.
-            To test the `legal_guardians` and `legal_wards` attributes, we need to create an
-            additional user and add their name to the corresponding attribute of the primary object.
         :return: The json used to create the user via the API
         """
         nonlocal _s_a_name
@@ -585,33 +575,6 @@ async def make_sender_user_special(
         user_obj: User = kelvin_user_object(
             roles, ous, session=kelvin_session(docker_hostname), **kwargs
         )
-
-        if create_related_users:
-            if "legal_guardian" in roles:
-                # to add users to the legal_wards attribute, we need to create a student
-                student_user_obj: User = kelvin_user_object(
-                    ("student",), ous, session=kelvin_session(docker_hostname), **kwargs
-                )
-                await student_user_obj.save()
-                await wait_for_kelvin_user_on_id_broker(
-                    s_a_name=s_a_name, school=student_user_obj.school, name=student_user_obj.name
-                )
-                created_users.append(student_user_obj.as_dict())
-                user_obj.legal_wards = [student_user_obj.name]
-            elif "student" in roles:
-                # to add users to the legal_guardians attribute, we need to create a student
-                legal_guardian_user_obj: User = kelvin_user_object(
-                    ("legal_guardian",), ous, session=kelvin_session(docker_hostname), **kwargs
-                )
-                await legal_guardian_user_obj.save()
-                await wait_for_kelvin_user_on_id_broker(
-                    s_a_name=s_a_name,
-                    school=legal_guardian_user_obj.school,
-                    name=legal_guardian_user_obj.name,
-                )
-                created_users.append(legal_guardian_user_obj.as_dict())
-                user_obj.legal_guardians = [legal_guardian_user_obj.name]
-
         password = user_obj.password
         await user_obj.save()
         user_obj.password = password
