@@ -173,8 +173,6 @@ def a_id_broker_user():
             user_name=fake.user_name(),
             first_name=fake.first_name(),
             last_name=fake.last_name(),
-            legal_guardians=[],
-            legal_wards=[],
             context={school_name: SchoolContext(classes=classes, roles=roles, workgroups=workgroups)},
         )
 
@@ -542,7 +540,7 @@ async def test_school_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_school_class_create(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -583,7 +581,7 @@ async def test_school_class_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_school_class_conflict_create(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -680,7 +678,7 @@ async def test_school_class_get(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_school_class_update(
     compare_kelvin_and_id_broker_school_class,
     get_kelvin_school_class,
@@ -758,7 +756,7 @@ async def test_school_class_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_workgroup_create(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -799,7 +797,7 @@ async def test_workgroup_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_workgroup_conflict_create(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -897,7 +895,7 @@ async def test_workgroup_get(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_workgroup_update(
     compare_kelvin_and_id_broker_workgroup,
     get_kelvin_workgroup,
@@ -975,7 +973,7 @@ async def test_workgroup_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_create(
     get_kelvin_user,
     schedule_delete_kelvin_school_class,
@@ -1010,7 +1008,7 @@ async def test_user_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_conflict_create(
     get_kelvin_user,
     schedule_delete_kelvin_school_class,
@@ -1050,7 +1048,7 @@ async def test_user_conflict_create(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_delete(
     get_kelvin_user,
     id_broker_fqdn: str,
@@ -1083,7 +1081,7 @@ async def test_user_delete(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_exists(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1116,7 +1114,7 @@ async def test_user_exists(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_get(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1146,7 +1144,7 @@ async def test_user_get(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_update(
     id_broker_fqdn: str,
     kelvin_session,
@@ -1196,7 +1194,7 @@ async def test_user_update(
 
 
 @pytest.mark.asyncio
-@pytest.mark.parametrize("roles", [["student"], ["teacher"], ["legal_guardian"]])
+@pytest.mark.parametrize("roles", [["student"], ["teacher"]])
 async def test_user_update_change_username(
     get_kelvin_user,
     id_broker_fqdn: str,
@@ -1240,125 +1238,3 @@ async def test_user_update_change_username(
         await get_kelvin_user(s_a_name, old_user_name)
     kelvin_user_2 = await get_kelvin_user(s_a_name, user_3.user_name)
     assert kelvin_user_2.name == f"{s_a_name}-{user_3.user_name}"
-
-
-@pytest.mark.asyncio
-@pytest.mark.parametrize("legal_ward_count", [1, 3], ids=lambda legal_ward_count: f"{legal_ward_count=}")
-async def test_legal_guardian_create(
-    id_broker_fqdn: str,
-    kelvin_session,
-    schedule_delete_kelvin_school_class,
-    schedule_delete_kelvin_user,
-    school_auth_conf: SchoolAuthorityConfiguration,
-    a_kelvin_user,
-    a_id_broker_user,
-    a_school_name,
-    legal_ward_count,
-):
-    """Test creation of a legal guardian
-
-    Create a legal guardian with some legal wards and check that
-    `legal_wards` and `legal_guardians` attributes on all related objects are correct
-    """
-    id_broker_user = IDBrokerUser(school_auth_conf, "id_broker")
-    s_a_name = id_broker_user.school_authority_name
-    school: str = await a_school_name(s_a_name)
-    class_name = fake.user_name()
-
-    kelvin_user_students: list[KelvinUser] = [
-        a_kelvin_user(
-            s_a_name=s_a_name,
-            session=kelvin_session(id_broker_fqdn),
-            school_name=school,
-            classes=[class_name],
-            roles=["student"],
-        )
-        for _ in range(legal_ward_count)
-    ]
-
-    legal_guardian_user: User = await a_id_broker_user(
-        school_name=school,
-        classes=[],
-        workgroups=[],
-        roles=["legal_guardian"],
-    )
-
-    legal_wards_record_uids = [
-        kelvin_user_student.record_uid for kelvin_user_student in kelvin_user_students
-    ]
-    legal_guardian_user.legal_wards = legal_wards_record_uids
-
-    schedule_delete_kelvin_school_class(s_a_name, class_name, school)
-
-    for kelvin_user_student in kelvin_user_students:
-        schedule_delete_kelvin_user(s_a_name, kelvin_user_student.name.split("-", 1)[-1])
-        await kelvin_user_student.save()
-
-    schedule_delete_kelvin_user(s_a_name, legal_guardian_user.user_name.split("-", 1)[-1])
-    await id_broker_user.create(legal_guardian_user)
-
-    for kelvin_user_student in kelvin_user_students:
-        student_user: User = await id_broker_user.get(kelvin_user_student.record_uid)
-        assert student_user.legal_guardians == [legal_guardian_user.id]
-
-    legal_guardian_user: User = await id_broker_user.get(legal_guardian_user.id)
-    assert set(legal_guardian_user.legal_wards) == set(legal_wards_record_uids)
-
-
-@pytest.mark.asyncio
-@pytest.mark.parametrize("legal_guardian_count", [1, 3])
-async def test_legal_ward_create(
-    id_broker_fqdn: str,
-    kelvin_session,
-    schedule_delete_kelvin_school_class,
-    schedule_delete_kelvin_user,
-    school_auth_conf: SchoolAuthorityConfiguration,
-    create_school_class,
-    a_kelvin_user,
-    a_id_broker_user,
-    a_school_name,
-    legal_guardian_count,
-):
-    id_broker_user = IDBrokerUser(school_auth_conf, "id_broker")
-    id_broker_sc = IDBrokerSchoolClass(school_auth_conf, "id_broker")
-
-    s_a_name = id_broker_user.school_authority_name
-    school: str = await a_school_name(s_a_name)
-    class_name = fake.user_name()
-
-    kelvin_user_legal_guardians: list[KelvinUser] = [
-        a_kelvin_user(
-            s_a_name=s_a_name,
-            session=kelvin_session(id_broker_fqdn),
-            school_name=school,
-            classes=[],
-            roles=["legal_guardian"],
-        )
-        for _ in range(legal_guardian_count)
-    ]
-
-    legal_ward_user: User = await a_id_broker_user(
-        school_name=school,
-        classes=[class_name],
-        workgroups=[],
-        roles=["student"],
-    )
-
-    legal_guardians_record_uids = [kelvin_user.record_uid for kelvin_user in kelvin_user_legal_guardians]
-    legal_ward_user.legal_guardians = legal_guardians_record_uids
-
-    await create_school_class(class_name, school, s_a_name, [], id_broker_sc)
-    schedule_delete_kelvin_school_class(s_a_name, class_name, school)
-
-    for kelvin_user in kelvin_user_legal_guardians:
-        schedule_delete_kelvin_user(s_a_name, kelvin_user.name.split("-", 1)[-1])
-        await kelvin_user.save()
-
-    schedule_delete_kelvin_user(s_a_name, legal_ward_user.user_name.split("-", 1)[-1])
-    await id_broker_user.create(legal_ward_user)
-    for kelvin_user_legal_guardian in kelvin_user_legal_guardians:
-        legal_guardian_user: User = await id_broker_user.get(kelvin_user_legal_guardian.record_uid)
-        assert legal_guardian_user.legal_wards == [legal_ward_user.id]
-
-    legal_ward_user: User = await id_broker_user.get(legal_ward_user.id)
-    assert set(legal_ward_user.legal_guardians) == set(legal_guardians_record_uids)
